@@ -194,7 +194,7 @@ use namespace::autoclean;
 use Class::Load;
 use Clone;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head2 data
 
@@ -296,7 +296,11 @@ has task_class => (
     is       => 'ro',
     isa      => 'Str',
     required => 1,
-    default  => 'Async::Simple::Task::Fork',
+    default  => (
+        $^O !~ /^(dos|os2|MSWin32|NetWare)$/
+            ? 'Async::Simple::Task::ForkTmpFile'
+            : 'Async::Simple::Task::Fork'
+    ),
 );
 
 
